import { useAjax } from '@/Hook/useAjax';
import { getCorpUserDayHourListApi } from '@/services/adqV3/monitorEWList';
import { Modal, Table } from 'antd';
import React, { useEffect, useState } from 'react';
import '../tencentAdPutIn/index.less';

interface AstraSupportHourProps {
    corpName: string;
    corpUserName: string;
    data: {
        day: string;
        corpId: string;
        corpUserId: string;
    }
}
const AstraSupportHour: React.FC<AstraSupportHourProps> = ({ corpName, corpUserName, data }) => {

    /***************************************/
    const [visible, setVisible] = useState<boolean>(false);

    const getCorpUserDayHourList = useAjax((params) => getCorpUserDayHourListApi(params))
    /***************************************/

    useEffect(() => {
        if (visible) {
            getCorpUserDayHourList.run(data)
        }
    }, [data, visible]);

    return <>
        <a style={{ fontSize: 12 }} onClick={() => setVisible(true)}>小时数据</a>
        {visible && <Modal
            title={<strong>{data.day}_{corpName}_{corpUserName} 小时数据</strong>}
            open={visible}
            onCancel={() => setVisible(false)}
            footer={null}
            className='modalResetCss'
            width={800}
        >
            <Table
                dataSource={getCorpUserDayHourList?.data}
                columns={[
                    {
                        title: '日期',
                        dataIndex: 'day',
                        key: 'day',
                        width: 80,
                        ellipsis: true,
                        align: 'center',
                        render(value) {
                            return <span style={{ fontSize: 12 }}>{value}</span>
                        },
                    },
                    {
                        title: '小时',
                        dataIndex: 'hour',
                        key: 'hour',
                        width: 80,
                        ellipsis: true,
                        align: 'center',
                        render(value) {
                            return <span style={{ fontSize: 12 }}>{value}</span>
                        },
                    },
                    {
                        title: '新增用户数',
                        dataIndex: 'addUserCount',
                        key: 'addUserCount',
                        width: 80,
                        ellipsis: true,
                        align: 'right',
                        render(value) {
                            return <span style={{ fontSize: 12 }}>{value}</span>
                        },
                    },
                    {
                        title: '退出人数',
                        dataIndex: 'outUserCount',
                        key: 'outUserCount',
                        width: 80,
                        ellipsis: true,
                        align: 'right',
                        render(value) {
                            return <span style={{ fontSize: 12 }}>{value}</span>
                        },
                    },
                    {
                        title: '数据更新时间',
                        dataIndex: 'dataTime',
                        key: 'dataTime',
                        width: 140,
                        ellipsis: true,
                        align: 'center',
                        render(value) {
                            return <span style={{ fontSize: 12 }}>{value}</span>
                        },
                    }
                ]}
                size='small'
                bordered
                rowKey={'id'}
                loading={getCorpUserDayHourList.loading}
                scroll={{ x: 750 }}
            />
        </Modal>}
    </>;
};

export default React.memo(AstraSupportHour);